Welcome to the lofar antenna positions documentation!
=====================================================

**lofarantpos** is a Python library containing LOFAR antenna positions, and tools for working with them.
The coordinates are mirrored from the official source: the `LOFAR git repository <https://git.astron.nl/ro/lofar>`_.

A convenience submodule is included for making matplotlib plots of (collections of) LOFAR stations.

.. image:: _images/plotutil-examples_8_0.png

Installation
------------

Installation is typically done with pip:

.. code-block:: console

   $ pip install --upgrade lofarantpos

Usage
-----
.. automodule:: db

Contents
--------
.. toctree::

   api
   plotutil-examples
